from argparse import ArgumentParser

import logging


class Log:
    @staticmethod
    def add_args(parser: ArgumentParser):
        verbosity = parser.add_mutually_exclusive_group()
        verbosity.add_argument('-v', dest='info', action='store_true', help='Log info messages')
        verbosity.add_argument('-vv', dest='debug', action='store_true', help='Log debug messages')

    @staticmethod
    def setup(args):
        if args.info:
            level = logging.INFO
        elif args.debug:
            level = logging.DEBUG
        else:
            level = logging.ERROR

        logging.basicConfig(level=level)



from obwsc.commands.event_based_command import EventBasedCommand

import logging

log = logging.getLogger('obwsc')


class StartRecord(EventBasedCommand):
    def __init__(self, config):
        super().__init__(config)
        self.events.callback.register(self.on_record_state_changed)

    @staticmethod
    def get_parser_name():
        return 'start-record'

    @staticmethod
    def get_help():
        return 'Start an OBS recording'

    def on_record_state_changed(self, event):
        if event.output_state == 'OBS_WEBSOCKET_OUTPUT_STARTED':
            self.done.set()

    def execute(self):
        status = self.ws.get_record_status()
        if status.output_active:
            log.debug('Recording is already running')
            self.done.set()
            return

        self.ws.start_record()
        self.done.wait()

